TagLanguageId

Enum TagLanguageId 

pub enum TagLanguageId {
Show 83 variants Afrikaans, Albanian, Arabic, Aramaic, Armenian, Bengali, Bosnian, Bulgarian, Burmese, Catalan, Cebuano, Chinese, Cree, Creole, Croatian, Czech, Danish, Dutch, English, Esperanto, Estonian, Finnish, French, Georgian, German, Greek, Gujarati, Hebrew, Hindi, Hmong, Hungarian, Icelandic, Indonesian, Irish, Italian, Japanese, Javanese, Kannada, Kazakh, Khmer, Korean, Kurdish, Ladino, Lao, Latin, Latvian, Marathi, Mongolian, Ndebele, Nepali, Norwegian, Oromo, Papiamento, Pashto, Persian, Polish, Portuguese, Punjabi, Romanian, Russian, Sango, Sanskrit, Serbian, Shona, Slovak, Slovenian, Somali, Spanish, Swahili, Swedish, Tagalog, Tamil, Telugu, Thai, Tibetan, Tigrinya, Turkish, Ukrainian, Urdu, Vietnamese, Welsh, Yiddish, Zulu,
}

Variants



Afrikaans



Albanian



Arabic



Aramaic



Armenian



Bengali



Bosnian



Bulgarian



Burmese



Catalan



Cebuano



Chinese



Cree



Creole



Croatian



Czech



Danish



Dutch



English



Esperanto



Estonian



Finnish



French



Georgian



German



Greek



Gujarati



Hebrew



Hindi



Hmong



Hungarian



Icelandic



Indonesian



Irish



Italian



Japanese



Javanese



Kannada



Kazakh



Khmer



Korean



Kurdish



Ladino



Lao



Latin



Latvian



Marathi



Mongolian



Ndebele



Nepali



Norwegian



Oromo



Papiamento



Pashto



Persian



Polish



Portuguese



Punjabi



Romanian



Russian



Sango



Sanskrit



Serbian



Shona



Slovak



Slovenian



Somali



Spanish



Swahili



Swedish



Tagalog



Tamil



Telugu



Thai



Tibetan



Tigrinya



Turkish



Ukrainian



Urdu



Vietnamese



Welsh



Yiddish



Zulu